pub struct TalentAttributeBonus {
pub attribute_id: AttributeId,
pub value: i64,
}Expand description
Бонус атрибута сущности от таланта (плоское значение)
Fields
attribute_id: AttributeIdvalue: i64Trait Implementations
Sourceimpl Clone for TalentAttributeBonus
impl Clone for TalentAttributeBonus
Sourcefn clone(&self) -> TalentAttributeBonus
fn clone(&self) -> TalentAttributeBonus
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TalentAttributeBonus
impl Debug for TalentAttributeBonus
Sourceimpl<'de> Deserialize<'de> for TalentAttributeBonus
impl<'de> Deserialize<'de> for TalentAttributeBonus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TalentAttributeBonus
impl JsonSchema for TalentAttributeBonus
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TalentAttributeBonus
impl Serialize for TalentAttributeBonus
Sourceimpl Tsify for TalentAttributeBonus
impl Tsify for TalentAttributeBonus
const DECL: &'static str = "/**\n * \u{411}\u{43e}\u{43d}\u{443}\u{441} \u{430}\u{442}\u{440}\u{438}\u{431}\u{443}\u{442}\u{430} \u{441}\u{443}\u{449}\u{43d}\u{43e}\u{441}\u{442}\u{438} \u{43e}\u{442} \u{442}\u{430}\u{43b}\u{430}\u{43d}\u{442}\u{430} (\u{43f}\u{43b}\u{43e}\u{441}\u{43a}\u{43e}\u{435} \u{437}\u{43d}\u{430}\u{447}\u{435}\u{43d}\u{438}\u{435})\n */\nexport interface TalentAttributeBonus {\n attribute_id: AttributeId;\n value: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>