pub struct TalentPosition {
pub col: i64,
pub row: i64,
}Expand description
Позиция таланта в дереве (для отрисовки на клиенте)
Fields
col: i64row: i64Trait Implementations
Sourceimpl Clone for TalentPosition
impl Clone for TalentPosition
Sourcefn clone(&self) -> TalentPosition
fn clone(&self) -> TalentPosition
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TalentPosition
impl Debug for TalentPosition
Sourceimpl<'de> Deserialize<'de> for TalentPosition
impl<'de> Deserialize<'de> for TalentPosition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TalentPosition
impl JsonSchema for TalentPosition
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TalentPosition
impl Serialize for TalentPosition
Sourceimpl Tsify for TalentPosition
impl Tsify for TalentPosition
const DECL: &'static str = "/**\n * \u{41f}\u{43e}\u{437}\u{438}\u{446}\u{438}\u{44f} \u{442}\u{430}\u{43b}\u{430}\u{43d}\u{442}\u{430} \u{432} \u{434}\u{435}\u{440}\u{435}\u{432}\u{435} (\u{434}\u{43b}\u{44f} \u{43e}\u{442}\u{440}\u{438}\u{441}\u{43e}\u{432}\u{43a}\u{438} \u{43d}\u{430} \u{43a}\u{43b}\u{438}\u{435}\u{43d}\u{442}\u{435})\n */\nexport interface TalentPosition {\n col: number;\n row: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>