pub struct TalentTemplate {
pub id: TalentId,
pub name: I18nString,
pub description: I18nString,
pub description_values_script: Option<String>,
pub icon_url: String,
pub icon_path: String,
pub levels: Vec<TalentLevel>,
pub unlock_condition: TalentUnlockCondition,
pub position: TalentPosition,
}Expand description
Шаблон таланта
Fields
id: TalentIdname: I18nStringdescription: I18nStringdescription_values_script: Option<String>icon_url: Stringicon_path: Stringlevels: Vec<TalentLevel>unlock_condition: TalentUnlockConditionposition: TalentPositionTrait Implementations
Sourceimpl Clone for TalentTemplate
impl Clone for TalentTemplate
Sourcefn clone(&self) -> TalentTemplate
fn clone(&self) -> TalentTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TalentTemplate
impl Debug for TalentTemplate
Sourceimpl<'de> Deserialize<'de> for TalentTemplate
impl<'de> Deserialize<'de> for TalentTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TalentTemplate
impl JsonSchema for TalentTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TalentTemplate
impl Serialize for TalentTemplate
Sourceimpl Tsify for TalentTemplate
impl Tsify for TalentTemplate
const DECL: &'static str = "/**\n * \u{428}\u{430}\u{431}\u{43b}\u{43e}\u{43d} \u{442}\u{430}\u{43b}\u{430}\u{43d}\u{442}\u{430}\n */\nexport interface TalentTemplate {\n id: TalentId;\n name: I18nString;\n description: I18nString;\n description_values_script: string | null;\n icon_url: string;\n icon_path: string;\n levels: TalentLevel[];\n unlock_condition: TalentUnlockCondition;\n position: TalentPosition;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>