pub struct TalentTreeSettings {
pub time_skip_ticket_skips_sec: u64,
pub skip_currency_id: CurrencyId,
pub skip_currency_skips_sec: u64,
}Expand description
Настройки дерева талантов
Fields
time_skip_ticket_skips_sec: u64skip_currency_id: CurrencyIdskip_currency_skips_sec: u64Trait Implementations
Sourceimpl Clone for TalentTreeSettings
impl Clone for TalentTreeSettings
Sourcefn clone(&self) -> TalentTreeSettings
fn clone(&self) -> TalentTreeSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TalentTreeSettings
impl Debug for TalentTreeSettings
Sourceimpl<'de> Deserialize<'de> for TalentTreeSettings
impl<'de> Deserialize<'de> for TalentTreeSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TalentTreeSettings
impl JsonSchema for TalentTreeSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TalentTreeSettings
impl Serialize for TalentTreeSettings
Sourceimpl Tsify for TalentTreeSettings
impl Tsify for TalentTreeSettings
const DECL: &'static str = "/**\n * \u{41d}\u{430}\u{441}\u{442}\u{440}\u{43e}\u{439}\u{43a}\u{438} \u{434}\u{435}\u{440}\u{435}\u{432}\u{430} \u{442}\u{430}\u{43b}\u{430}\u{43d}\u{442}\u{43e}\u{432}\n */\nexport interface TalentTreeSettings {\n time_skip_ticket_skips_sec: number;\n skip_currency_id: CurrencyId;\n skip_currency_skips_sec: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>